@@ -1,3 +1,4 @@
+from __future__ import annotations
 import time
 
 import numpy as np
@@ -13,11 +14,17 @@ class Aviary(bullet_client.BulletClient):
         self,
         start_pos: np.ndarray,
         start_orn: np.ndarray,
-        render=False,
-        use_camera=False,
-        physics_hz=240.0,
-        ctrl_hz=120.0,
-        camera_frame_size=(128, 128),
+        render: bool = False,
+        physics_hz: int = 240,
+        ctrl_hz: int = 120,
+        model_dir: None | str = None,
+        drone_model: str = "cf2x",
+        use_camera: bool = False,
+        use_gimbal: bool = False,
+        camera_angle: int = 20,
+        camera_FOV: int = 90,
+        camera_frame_size: tuple[int, int] = (128, 128),
+        seed: None | int = None,
     ):
         super().__init__(p.GUI if render else p.DIRECT)
         print("\033[A                             \033[A")
@@ -34,9 +41,13 @@ class Aviary(bullet_client.BulletClient):
         self.start_pos = start_pos
         self.start_orn = start_orn
         self.use_camera = use_camera
+        self.use_gimbal = use_gimbal
+        self.camera_angle = camera_angle
+        self.camera_FOV = camera_FOV
         self.camera_frame_size = camera_frame_size
 
-        self.drone_model = "cf2x"
+        self.model_dir = model_dir
+        self.drone_model = drone_model
         self.setAdditionalSearchPath(pybullet_data.getDataPath())
 
         self.render = render
@@ -44,13 +55,16 @@ class Aviary(bullet_client.BulletClient):
             text="RTF here", textPosition=[0, 0, 0], textColorRGB=[1, 0, 0]
         )
 
-        self.reset()
+        self.reset(seed)
 
-    def reset(self):
+    def reset(self, seed: None | int = None):
         self.resetSimulation()
         self.setGravity(0, 0, -9.81)
         self.steps = 0
 
+        # define new RNG
+        self.np_random = np.random.RandomState(seed=seed)
+
         """ CONSTRUCT THE WORLD """
         self.planeId = self.loadURDF("plane.urdf", useFixedBase=True, globalScaling=1.0)
         # p.changeVisualShape(
@@ -69,9 +83,14 @@ class Aviary(bullet_client.BulletClient):
                     start_orn=start_orn,
                     ctrl_hz=self.ctrl_hz,
                     physics_hz=self.physics_hz,
+                    model_dir=self.model_dir,
                     drone_model=self.drone_model,
                     use_camera=self.use_camera,
+                    use_gimbal=self.use_gimbal,
+                    camera_angle=self.camera_angle,
+                    camera_FOV=self.camera_FOV,
                     camera_frame_size=self.camera_frame_size,
+                    np_random=self.np_random,
                 )
             )
 
